==> mutual_credit-5.0.1.tar.gz: mutual_credit/src/Entity/ListBuilder/CurrencyListBuilder.php <==
<?php

namespace Drupal\mcapi\Entity\ListBuilder;

use Drupal\Core\Config\Entity\DraggableListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Render\Element;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\EntityStorageInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a listing of currencies.
 * @todo there's a problem with the draggable table
 */
class CurrencyListBuilder extends DraggableListBuilder {

  /**
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  public function __construct(EntityTypeInterface $entity_type, EntityStorageInterface $storage, EntityTypeManagerInterface $entity_type_manager) {
    parent::__construct($entity_type, $storage);
    $this->entityTypeManager = $entity_type_manager;
  }


  /**
   * {@inheritdoc}
   */
  public static function createInstance(ContainerInterface $container, EntityTypeInterface $entity_type) {
    return new static(
      $entity_type,
      $container->get('entity_type.manager')->getStorage('mcapi_currency'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'mcapi_currency_collection';
  }

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['title'] = t('Title');
    $header['volume'] = t('Volume');
    $header['trades'] = t('Trades');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $currency) {
    $actions = parent::buildRow($currency);
    if (empty($actions)) {
      return;
    }
    if ($currency->access('view')) {
      $title = $currency->toLink()->toString();
    }
    else {
      $title = $currency->label();
    }
    $row['title'] = ['#markup' => $title];
    $stats = $this->entityTypeManager
      ->getStorage('mcapi_transaction')
      ->ledgerStateQuery($currency->id(), [])
      ->execute()
      ->fetch();
    // This includes deleted transactions.
    $row['volume'] = [
      '#markup' => $currency->format($stats->volume),
    ];
    $row['trades'] = [
      '#markup' => $stats->trades,
    ];
    // A currency with transactions in the database must not be deleted.
    if ($stats->trades) {
      unset($actions['operations']['data']['#links']['delete']);
    }
    return $row + $actions;
  }

  /**
   * Remove the delete link if there is only one currency.
   */
  public function render() {
    $build = parent::render();
    $children = Element::children($build['entities']);
    if (count($children) == 1) {
      $id = reset($children);
      unset($build['entities'][$id]['operations']['data']['#links']['delete']);
    }
    return $build;

  }

}

==> mutual_credit-5.0.5.tar.gz: mutual_credit/src/Entity/ListBuilder/CurrencyListBuilder.php <==
<?php

namespace Drupal\mcapi\Entity\ListBuilder;

use Drupal\Core\Config\Entity\DraggableListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Render\Element;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\EntityStorageInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a listing of currencies.
 * @todo there's a problem with the draggable table
 */
class CurrencyListBuilder extends DraggableListBuilder {

  /**
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  public function __construct(EntityTypeInterface $entity_type, EntityStorageInterface $storage, EntityTypeManagerInterface $entity_type_manager) {
    parent::__construct($entity_type, $storage);
    $this->entityTypeManager = $entity_type_manager;
  }


  /**
   * {@inheritdoc}
   */
  public static function createInstance(ContainerInterface $container, EntityTypeInterface $entity_type) {
    return new static(
      $entity_type,
      $container->get('entity_type.manager')->getStorage('mcapi_currency'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'mcapi_currency_collection';
  }

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['title'] = t('Title');
    $header['volume'] = t('Volume');
    $header['trades'] = t('Trades');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $currency) {
    $actions = parent::buildRow($currency);
    if (empty($actions)) {
      return;
    }
    if ($currency->access('view')) {
      $title = $currency->toLink()->toString();
    }
    else {
      $title = $currency->label();
    }
    $row['title'] = ['#markup' => $title];
    $stats = $this->entityTypeManager
      ->getStorage('mcapi_transaction')
      ->ledgerStateQuery($currency->id(), [])
      ->execute()
      ->fetch();
    // This includes deleted transactions.
    $row['volume'] = [
      '#markup' => $currency->format((int)$stats->volume),
    ];
    $row['trades'] = [
      '#markup' => $stats->trades,
    ];
    // A currency with transactions in the database must not be deleted.
    if ($stats->trades) {
      unset($actions['operations']['data']['#links']['delete']);
    }
    return $row + $actions;
  }

  /**
   * Remove the delete link if there is only one currency.
   */
  public function render() {
    $build = parent::render();
    $children = Element::children($build['entities']);
    if (count($children) == 1) {
      $id = reset($children);
      unset($build['entities'][$id]['operations']['data']['#links']['delete']);
    }
    return $build;

  }

}
